@@ -20,6 +20,13 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#endif
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <libxfce4util/libxfce4util.h>
@@ -99,6 +106,7 @@ static gboolean      xfce_panel_plugin_remote_event           (XfcePanelPluginPr
                                                                guint                            *handle);
 static void          xfce_panel_plugin_set_locked             (XfcePanelPluginProvider          *provider,
                                                                gboolean                          locked);
+static void          xfce_panel_plugin_ask_remove             (XfcePanelPluginProvider          *provider);
 static void          xfce_panel_plugin_take_window_notify     (gpointer                          data,
                                                                GObject                          *where_the_object_was);
 static void          xfce_panel_plugin_menu_item_destroy      (GtkWidget                        *item,
@@ -583,6 +591,13 @@ xfce_panel_plugin_init (XfcePanelPlugin *plugin)
   plugin->priv->locked = TRUE;
   plugin->priv->menu_items = NULL;
 
+  /* bind the text domain of the panel so our strings
+   * are properly translated in the old 4.6 panel plugins */
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+
   /* hide the event box window to make the plugin transparent */
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (plugin), FALSE);
 }
@@ -605,6 +620,7 @@ xfce_panel_plugin_provider_init (XfcePanelPluginProviderInterface *iface)
   iface->removed = xfce_panel_plugin_removed;
   iface->remote_event = xfce_panel_plugin_remote_event;
   iface->set_locked = xfce_panel_plugin_set_locked;
+  iface->ask_remove = xfce_panel_plugin_ask_remove;
 }
 
 
@@ -1377,6 +1393,16 @@ xfce_panel_plugin_set_locked (XfcePanelPluginProvider *provider,
 
 
 
+static void
+xfce_panel_plugin_ask_remove (XfcePanelPluginProvider *provider)
+{
+  panel_return_if_fail (XFCE_IS_PANEL_PLUGIN (provider));
+
+  xfce_panel_plugin_menu_remove (XFCE_PANEL_PLUGIN (provider));
+}
+
+
+
 static void
 xfce_panel_plugin_take_window_notify (gpointer  data,
                                       GObject  *where_the_object_was)
