@@ -121,7 +121,7 @@ panel_callback_handler (const gchar  *name,
 static void
 panel_signal_handler (gint signum)
 {
-  panel_debug (PANEL_DEBUG_DOMAIN_MAIN,
+  panel_debug (PANEL_DEBUG_MAIN,
                "received signal %s <%d>, %s panel",
                g_strsignal (signum), signum,
                signum == SIGUSR1 ? "restarting" : "quiting");
@@ -137,7 +137,7 @@ panel_sm_client_quit (XfceSMClient *sm_client)
   panel_return_if_fail (XFCE_IS_SM_CLIENT (sm_client));
   panel_return_if_fail (!panel_dbus_service_get_restart ());
 
-  panel_debug (PANEL_DEBUG_DOMAIN_MAIN,
+  panel_debug (PANEL_DEBUG_MAIN,
                "terminate panel for session manager");
 
   gtk_main_quit ();
@@ -152,7 +152,7 @@ panel_sm_client_save_state (XfceSMClient     *sm_client,
   panel_return_if_fail (XFCE_IS_SM_CLIENT (sm_client));
   panel_return_if_fail (PANEL_IS_APPLICATION (application));
 
-  panel_debug (PANEL_DEBUG_DOMAIN_MAIN,
+  panel_debug (PANEL_DEBUG_MAIN,
                "save configuration for session manager");
 
   panel_application_save (application, TRUE);
@@ -162,6 +162,47 @@ panel_sm_client_save_state (XfceSMClient     *sm_client,
 
 
 
+static void
+panel_debug_notify_proxy (void)
+{
+  gchar       *path;
+  const gchar *proxy_cmd;
+
+  if (G_UNLIKELY (panel_debug_has_domain (PANEL_DEBUG_GDB)))
+    proxy_cmd = "gdb";
+  else if (G_UNLIKELY (panel_debug_has_domain (PANEL_DEBUG_VALGRIND)))
+    proxy_cmd = "valgrind";
+  else
+    return;
+
+  path = g_find_program_in_path (proxy_cmd);
+  if (G_LIKELY (path != NULL))
+    {
+      panel_debug (PANEL_DEBUG_MAIN,
+                   "running external plugins with %s, logs stored in %s",
+                   path, g_get_tmp_dir ());
+      g_free (path);
+
+      if (panel_debug_has_domain (PANEL_DEBUG_GDB))
+        {
+          /* performs sanity checks on the released memory slices */
+          g_setenv ("G_SLICE", "debug-blocks", TRUE);
+        }
+      else if (panel_debug_has_domain (PANEL_DEBUG_VALGRIND))
+        {
+          /* use g_malloc() and g_free() instead of slices */
+          g_setenv ("G_SLICE", "always-malloc", TRUE);
+          g_setenv ("G_DEBUG", "gc-friendly", TRUE);
+        }
+    }
+  else
+    {
+      panel_debug (PANEL_DEBUG_MAIN, "%s not found in PATH", proxy_cmd);
+    }
+}
+
+
+
 gint
 main (gint argc, gchar **argv)
 {
@@ -175,7 +216,7 @@ main (gint argc, gchar **argv)
   const gchar      *error_msg;
   XfceSMClient     *sm_client;
 
-  panel_debug (PANEL_DEBUG_DOMAIN_MAIN,
+  panel_debug (PANEL_DEBUG_MAIN,
                "version %s on gtk+ %d.%d.%d (%d.%d.%d), glib %d.%d.%d (%d.%d.%d)",
                LIBXFCE4PANEL_VERSION,
                gtk_major_version, gtk_minor_version, gtk_micro_version,
@@ -183,6 +224,9 @@ main (gint argc, gchar **argv)
                glib_major_version, glib_minor_version, glib_micro_version,
                GLIB_MAJOR_VERSION, GLIB_MINOR_VERSION, GLIB_MICRO_VERSION);
 
+  /* inform the user about usage of gdb/valgrind */
+  panel_debug_notify_proxy ();
+
   /* set translation domain */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
@@ -363,7 +407,7 @@ dbus_return:
                                          "automatically started the next time you login."),
                                        _("No running instance of %s was found"), G_LOG_DOMAIN))
                 {
-                  panel_debug (PANEL_DEBUG_DOMAIN_MAIN, "user confirmed to start the panel");
+                  panel_debug (PANEL_DEBUG_MAIN, "user confirmed to start the panel");
                   goto launch_panel;
                 }
               else
