@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,19 +78,19 @@ static void      panel_application_drag_data_received (PanelWindow            *w
                                                        guint                   info,
                                                        guint                   drag_time,
                                                        GtkWidget              *itembar);
-static gboolean  panel_application_drag_motion        (GtkWidget              *itembar,
+static gboolean  panel_application_drag_motion        (GtkWidget              *window,
                                                        GdkDragContext         *context,
                                                        gint                    x,
                                                        gint                    y,
                                                        guint                   drag_time,
                                                        PanelApplication       *application);
-static gboolean  panel_application_drag_drop          (GtkWidget              *itembar,
+static gboolean  panel_application_drag_drop          (GtkWidget              *window,
                                                        GdkDragContext         *context,
                                                        gint                    x,
                                                        gint                    y,
                                                        guint                   drag_time,
                                                        PanelApplication       *application);
-static void      panel_application_drag_leave         (GtkWidget              *itembar,
+static void      panel_application_drag_leave         (GtkWidget              *window,
                                                        GdkDragContext         *context,
                                                        guint                   drag_time,
                                                        PanelApplication       *application);
@@ -176,8 +176,7 @@ panel_application_class_init (PanelApplicationClass *klass)
 static void
 panel_application_init (PanelApplication *application)
 {
-  PanelWindow *window;
-  GError      *error = NULL;
+  GError *error = NULL;
 
   application->windows = NULL;
   application->dialogs = NULL;
@@ -217,7 +216,7 @@ panel_application_init (PanelApplication *application)
 
   /* create empty window if everything else failed */
   if (G_UNLIKELY (application->windows == NULL))
-    window = panel_application_new_window (application, NULL, TRUE);
+    panel_application_new_window (application, NULL, TRUE);
 }
 
 
@@ -245,7 +244,7 @@ panel_application_finalize (GObject *object)
   g_object_unref (G_OBJECT (application->factory));
 
   /* this is a good reference if all the objects are released */
-  panel_debug (PANEL_DEBUG_DOMAIN_APPLICATION, "finalized");
+  panel_debug (PANEL_DEBUG_APPLICATION, "finalized");
 
   (*G_OBJECT_CLASS (panel_application_parent_class)->finalize) (object);
 }
@@ -364,6 +363,23 @@ panel_application_load (PanelApplication *application)
 
 
 
+static void
+panel_application_plugin_move_drag_data_get (GtkWidget        *item,
+                                             GdkDragContext   *drag_context,
+                                             GtkSelectionData *selection_data,
+                                             guint             info,
+                                             guint             drag_time,
+                                             PanelApplication *application)
+{
+  /* set some data, we never use this, but GTK_DEST_DEFAULT_ALL
+   * used in the item dialog requires this */
+  gtk_selection_data_set (selection_data,
+                          selection_data->target, 8,
+                          (const guchar *) "0", 1);
+}
+
+
+
 static void
 panel_application_plugin_move_drag_end (GtkWidget        *item,
                                         GdkDragContext   *context,
@@ -375,6 +391,8 @@ panel_application_plugin_move_drag_end (GtkWidget        *item,
   /* disconnect this signal */
   g_signal_handlers_disconnect_by_func (G_OBJECT (item),
       G_CALLBACK (panel_application_plugin_move_drag_end), application);
+  g_signal_handlers_disconnect_by_func (G_OBJECT (item),
+      G_CALLBACK (panel_application_plugin_move_drag_data_get), application);
 
   /* make the window sensitive again */
   panel_application_windows_sensitive (application, TRUE);
@@ -416,6 +434,8 @@ panel_application_plugin_move (GtkWidget        *item,
   /* signal to make the window sensitive again on a drag end */
   g_signal_connect (G_OBJECT (item), "drag-end",
       G_CALLBACK (panel_application_plugin_move_drag_end), application);
+  g_signal_connect (G_OBJECT (item), "drag-data-get",
+      G_CALLBACK (panel_application_plugin_move_drag_data_get), application);
 }
 
 
@@ -868,7 +888,9 @@ panel_application_drag_data_received (PanelWindow      *window,
           else
             {
               /* reparent the widget, this will also call remove and add for the itembar */
+              gtk_widget_hide (provider);
               gtk_widget_reparent (provider, itembar);
+              gtk_widget_show (provider);
 
               /* move the item to the correct position on the itembar */
               panel_itembar_reorder_child (PANEL_ITEMBAR (itembar), provider, application->drop_index);
@@ -1090,7 +1112,7 @@ panel_application_save (PanelApplication *application,
       if (panel_window_get_locked (li->data))
         continue;
 
-      panel_debug (PANEL_DEBUG_DOMAIN_APPLICATION,
+      panel_debug (PANEL_DEBUG_APPLICATION,
                    "saving /panels/panel-%u, save-plugins=%s",
                    i, PANEL_DEBUG_BOOL (save_plugin_providers));
 
@@ -1360,18 +1382,13 @@ void
 panel_application_windows_sensitive (PanelApplication *application,
                                      gboolean          sensitive)
 {
-  GtkWidget *itembar;
-  GSList    *li;
+  GSList *li;
 
   panel_return_if_fail (PANEL_IS_APPLICATION (application));
 
   /* walk the windows */
   for (li = application->windows; li != NULL; li = li->next)
     {
-      /* set sensitivity of the itembar (and the plugins) */
-      itembar = gtk_bin_get_child (GTK_BIN (li->data));
-      gtk_widget_set_sensitive (itembar, sensitive);
-
       /* block autohide for all windows */
       if (sensitive)
         panel_window_thaw_autohide (PANEL_WINDOW (li->data));
