@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -835,12 +835,10 @@ panel_itembar_get_drop_index (PanelItembar *itembar,
 
   /* add the itembar position */
   alloc = &GTK_WIDGET (itembar)->allocation;
-  x += alloc->x;
-  y += alloc->y;
 
   /* return -1 if point is outside the widget allocation */
   if (x > alloc->width || y > alloc->height)
-    return -1;
+    return g_slist_length (itembar->children);
 
   for (li = itembar->children, idx = 0; li != NULL; li = g_slist_next (li))
     {
