@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2009-2010 Nick Schermer <nick@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1014,6 +1014,8 @@ panel_window_grab_notify (GtkWidget *widget,
 {
   PanelWindow *window = PANEL_WINDOW (widget);
   GtkWidget   *current;
+  GdkScreen   *screen;
+  gint         x, y;
 
   current = gtk_grab_get_current ();
   if (GTK_IS_MENU_SHELL (current))
@@ -1024,11 +1026,31 @@ panel_window_grab_notify (GtkWidget *widget,
     }
   else if (window->autohide_grab_block > 0)
     {
-      /* drop previous menu block */
+      /* drop previous menu block or grab from outside window */
       window->autohide_grab_block--;
     }
   else if (window->autohide_grab_block == 0)
     {
+      if (current != NULL)
+        {
+          gdk_display_get_pointer (gtk_widget_get_display (current),
+                                   &screen, &x, &y, NULL);
+
+          /* filter out grab event that did not occur in the panel window,
+           * but in a windows that is part of this process */
+          if (gtk_window_get_screen (GTK_WINDOW (window)) != screen
+              || x < window->alloc.x
+              || x > window->alloc.x + window->alloc.width
+              || y < window->alloc.y
+              || y > window->alloc.y + window->alloc.height)
+            {
+              /* block the next notification */
+              window->autohide_grab_block++;
+
+              return;
+            }
+       }
+
       /* avoid hiding the panel when the window is grabbed. this
        * (for example) happens when the user drags in the pager plugin
        * see bug #4597 */
@@ -1405,7 +1427,7 @@ panel_window_screen_struts_set (PanelWindow *window)
   GdkRectangle  *alloc = &window->alloc;
   guint          i;
   gboolean       update_struts = FALSE;
-  gint           n = -1;
+  gint           n;
   const gchar   *strut_border[] = { "left", "right", "top", "bottom" };
   const gchar   *strut_xy[] = { "y", "y", "x", "x" };
 
@@ -1485,8 +1507,10 @@ panel_window_screen_struts_set (PanelWindow *window)
   if (gdk_error_trap_pop () != 0)
     g_critical ("Failed to set the struts");
 
-  if (G_UNLIKELY (panel_debug_flags != 0))
+  if (panel_debug_has_domain (PANEL_DEBUG_YES))
     {
+      n = -1;
+
       if (struts[STRUT_LEFT] != 0)
         n = STRUT_LEFT;
       else if (struts[STRUT_RIGHT] != 0)
@@ -1496,11 +1520,11 @@ panel_window_screen_struts_set (PanelWindow *window)
       else if (struts[STRUT_BOTTOM] != 0)
         n = STRUT_BOTTOM;
       else
-        panel_debug (PANEL_DEBUG_DOMAIN_STRUTS, "unset");
+        panel_debug (PANEL_DEBUG_STRUTS, "unset");
 
       if (n != -1)
         {
-          panel_debug (PANEL_DEBUG_DOMAIN_STRUTS,
+          panel_debug (PANEL_DEBUG_STRUTS,
                        "%s=%ld, start_%s=%ld, end_%s=%ld",
                        strut_border[n], struts[n],
                        strut_xy[n], struts[4 + n * 2],
@@ -1669,7 +1693,7 @@ panel_window_display_layout_debug (GtkWidget *widget)
   gchar        *name;
 
   panel_return_if_fail (GTK_IS_WIDGET (widget));
-  panel_return_if_fail (panel_debug_flags != 0);
+  panel_return_if_fail (panel_debug_has_domain (PANEL_DEBUG_YES));
 
   str = g_string_new (NULL);
 
@@ -1704,7 +1728,7 @@ panel_window_display_layout_debug (GtkWidget *widget)
         g_string_append (str, ", ");
     }
 
-  panel_debug (PANEL_DEBUG_DOMAIN_DISPLAY_LAYOUT,
+  panel_debug (PANEL_DEBUG_DISPLAY_LAYOUT,
                "display %s: %s",
                gdk_display_get_name (display), str->str);
 
@@ -1736,7 +1760,7 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
     return;
 
   /* print the display layout when debugging is enabled */
-  if (G_UNLIKELY (panel_debug_flags != 0))
+  if (G_UNLIKELY (panel_debug_has_domain (PANEL_DEBUG_YES)))
     panel_window_display_layout_debug (GTK_WIDGET (window));
 
   /* update the struts edge of this window and check if we need to force
@@ -1750,7 +1774,7 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
   n_monitors = gdk_screen_get_n_monitors (screen);
   panel_return_if_fail (n_monitors > 0);
 
-  panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+  panel_debug (PANEL_DEBUG_POSITIONING,
                "monitors=%d, output-name=%s, span-monitors=%s, base=%d,%d",
                n_monitors, window->output_name,
                PANEL_DEBUG_BOOL (window->span_monitors),
@@ -1776,9 +1800,9 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
       if (gdk_screen_get_number (screen) != screen_num)
         {
           display = gdk_screen_get_display (screen);
-          if (gdk_display_get_n_screens (display) - 1 > screen_num)
+          if (gdk_display_get_n_screens (display) - 1 < screen_num)
             {
-              panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+              panel_debug (PANEL_DEBUG_POSITIONING,
                            "screen-%d not found, hiding panel", screen_num);
 
               /* out of range, hide the window */
@@ -1788,7 +1812,7 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
             }
           else
             {
-              panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+              panel_debug (PANEL_DEBUG_POSITIONING,
                            "moving panel from screen %d to %d",
                            gdk_screen_get_number (screen),
                            screen_num);
@@ -1865,7 +1889,7 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
 
           if (G_UNLIKELY (monitor_num == -1))
             {
-              panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+              panel_debug (PANEL_DEBUG_POSITIONING,
                            "output/monitor %s not found, hiding window",
                            window->output_name);
 
@@ -1919,13 +1943,13 @@ panel_window_screen_layout_changed (GdkScreen   *screen,
             }
         }
 
-      panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+      panel_debug (PANEL_DEBUG_POSITIONING,
                    "struts edge: %d", window->struts_edge);
     }
 
   /* set the new working area of the panel */
   window->area = a;
-  panel_debug (PANEL_DEBUG_DOMAIN_POSITIONING,
+  panel_debug (PANEL_DEBUG_POSITIONING,
                "working-area: x=%d, y=%d, w=%d, h=%d",
                a.x, a.y, a.width, a.height);
 
