@@ -26,6 +26,7 @@
 #include <common/panel-private.h>
 #include <common/panel-xfconf.h>
 #include <common/panel-utils.h>
+#include <common/panel-debug.h>
 #include <exo/exo.h>
 
 #include "systray.h"
@@ -416,6 +417,14 @@ systray_plugin_screen_changed (GtkWidget *widget,
 }
 
 
+static void
+systray_plugin_composited_changed (GtkWidget *widget)
+{
+  /* restart the manager to add the sockets again */
+  systray_plugin_screen_changed (widget, gtk_widget_get_screen (widget));
+}
+
+
 
 static void
 systray_plugin_construct (XfcePanelPlugin *panel_plugin)
@@ -440,6 +449,10 @@ systray_plugin_construct (XfcePanelPlugin *panel_plugin)
   g_signal_connect (G_OBJECT (plugin), "screen-changed",
       G_CALLBACK (systray_plugin_screen_changed), NULL);
   systray_plugin_screen_changed (GTK_WIDGET (plugin), NULL);
+
+  /* restart internally if compositing changed */
+  g_signal_connect (G_OBJECT (plugin), "composited-changed",
+     G_CALLBACK (systray_plugin_composited_changed), NULL);
 }
 
 
@@ -797,6 +810,9 @@ systray_plugin_icon_added (SystrayManager *manager,
   systray_plugin_names_update_icon (icon, plugin);
   gtk_container_add (GTK_CONTAINER (plugin->box), icon);
   gtk_widget_show (icon);
+
+  panel_debug_filtered (PANEL_DEBUG_SYSTRAY, "added %s icon",
+      systray_socket_get_name (XFCE_SYSTRAY_SOCKET (icon)));
 }
 
 
@@ -813,6 +829,9 @@ systray_plugin_icon_removed (SystrayManager *manager,
 
   /* remove the icon from the box */
   gtk_container_remove (GTK_CONTAINER (plugin->box), icon);
+
+  panel_debug_filtered (PANEL_DEBUG_SYSTRAY, "removed %s icon",
+      systray_socket_get_name (XFCE_SYSTRAY_SOCKET (icon)));
 }
 
 
